@@ -6,10 +6,22 @@ Path.cwd()
 #import pynmea2
 now = datetime.datetime.now()
 #print("Make sure there is no other File in the path except .nmea file only ")
+def find(res):
+    sel="GP"
+    d=res.split(',')
+    if len(d[0].split('GP'))>1:
+        sel='GP'
+    elif len(d[0].split('GI'))>1:
+        sel='GI'
+    elif len(d[0].split('GN'))>1:
+        sel='GN'
+    op=d[0].split(sel)[-1]
+    return op
+
 
 class GPGSVrec:
     def __init__(self, res):
-        print("Global Positioning System Fixed Data\n")
+        print("Satellites in View\n")
         self.res=res
         d=res.split(',')
         self.nofmsg=d[1]
@@ -170,20 +182,10 @@ class GPVTGrec:
         x=self
         self.print=("True track made good: "+x.ttm+" Magnetic track made good: "+x.mtm+" Ground speed, knots: "+x.gspeedn+" Ground speed, Kilometers per hour: "+x.gspeedk+"\n")
 
-def find(res):
-    d=res.split(',')
-    if len(d[0].split('GP'))>1:
-        sel='GP'
-    elif len(d[0].split('GI'))>1:
-        sel='GI'
-    elif len(d[0].split('GN'))>1:
-        sel='GN'
-    op=d[0].split(sel)[-1]
-    return op
     
     
 class imp:
-    def allnmea():
+    def docs():
         print(" opSel() , sampleFile()")
         print("Classes used: msg=GPGGArec(res),x=GPGSArec(res),x=GPRMCrec(res),x=GPVTGrec(res), x=GPZDArec(res), x=GPGSVrec(res) \n")
         print("#$GPGGA,124632.122,5231.537,N,01320.203,E,1,12,1.0,0.0,M,0.0,M,,*6A \n #$GPGSA,A,3,01,02,03,04,05,06,07,08,09,10,11,12,1.0,1.0,1.0*30\n #$GPRMC,124633.122,A,5231.938,N,01324.385,E,2228.2,011.3,020622,000.0,W*48\n #$GPZDA,181813,14,10,2003,00,00*4F\n #$GPVTG,309.62,T, ,M,0.13,N,0.2,K,A*23\n #$GPGSV,2,1,07,07,79,048,42,02,51,062,43,26,36,256,42,27,27,138,42*71")
@@ -280,7 +282,7 @@ class readNmea():
                 elif res1=='GSV':
                     print(res)
                     x=GPGSVrec(res)
-                    x.print()
+                    x.print
                     
 
 #$GPGGA,124632.122,5231.537,N,01320.203,E,1,12,1.0,0.0,M,0.0,M,,*6A
